@@ -1,9 +1,12 @@
 #include <filezilla.h>
 #include "local_path.h"
+#include "string_coalescer.h"
 #ifndef __WXMSW__
 #include <errno.h>
 #endif
 
+#include <deque>
+
 #ifdef __WXMSW__
 const wxChar CLocalPath::path_separator = '\\';
 #else
@@ -30,7 +33,7 @@ bool CLocalPath::SetPath(const wxString& path, wxString* file /*=0*/)
 		return false;
 	}
 
-	std::list<wxChar*> segments; // List to store the beginnings of segments
+	std::deque<wxChar*> segments; // List to store the beginnings of segments
 
 	const wxChar* in = path.c_str();
 
@@ -44,6 +47,7 @@ bool CLocalPath::SetPath(const wxString& path, wxString* file /*=0*/)
 	}
 
 	wxChar* out;
+	wxChar* start;
 	if (*in == '\\')
 	{
 		// possibly UNC
@@ -55,8 +59,8 @@ bool CLocalPath::SetPath(const wxString& path, wxString* file /*=0*/)
 			return false;
 		}
 
-		wxChar* buf = m_path.GetWriteBuf(path.Len() + 2);
-		out = buf;
+		start = m_path.GetWriteBuf(path.Len() + 2);
+		out = start;
 		*out++ = '\\';
 		*out++ = '\\';
 
@@ -69,34 +73,35 @@ bool CLocalPath::SetPath(const wxString& path, wxString* file /*=0*/)
 		}
 		*out++ = path_separator;
 
-		if (out - buf <= 3)
+		if (out - start <= 3)
 		{
 			// not a valid UNC path
-			*buf = 0;
-			m_path.UngetWriteBuf();
+			*start = 0;
+			m_path.UngetWriteBuf( 0 );
 			return false;
 		}
+
 		segments.push_back(out);
 	}
 	else if ((*in >= 'a' && *in <= 'z') || (*in >= 'A' || *in <= 'Z'))
 	{
 		// Regular path
 
-		wxChar* buf = m_path.GetWriteBuf(path.Len() + 2);
-		out = buf;
+		start = m_path.GetWriteBuf(path.Len() + 2);
+		out = start;
 		*out++ = *in++;
 
 		if (*in++ != ':')
 		{
-			*buf = 0;
-			m_path.UngetWriteBuf();
+			*start = 0;
+			m_path.UngetWriteBuf( 0 );
 			return false;
 		}
 		*out++ = ':';
 		if (*in != '/' && *in != '\\' && *in)
 		{
-			*buf = 0;
-			m_path.UngetWriteBuf();
+			*start = 0;
+			m_path.UngetWriteBuf( 0 );
 			return false;
 		}
 		*out++ = path_separator;
@@ -115,7 +120,9 @@ bool CLocalPath::SetPath(const wxString& path, wxString* file /*=0*/)
 		return false;
 	}
 
-	wxChar* out = m_path.GetWriteBuf(path.Len() + 2);
+	wxChar* start = m_path.GetWriteBuf(path.Len() + 2);
+	wxChar* out = start;
+
 	*out++ = '/';
 	segments.push_back(out);
 #endif
@@ -204,7 +211,10 @@ bool CLocalPath::SetPath(const wxString& path, wxString* file /*=0*/)
 
 	*out = 0;
 
-	m_path.UngetWriteBuf();
+	m_path.UngetWriteBuf( out - start );
+
+	::Coalesce(m_path);
+
 	return true;
 }
 
@@ -585,3 +595,8 @@ wxString CLocalPath::GetLastSegment() const
 
 	return _T("");
 }
+
+void CLocalPath::Coalesce()
+{
+	::Coalesce(m_path);
+}
\ No newline at end of file
