@@ -50,7 +50,7 @@ DEFINE_EVENT_TYPE(fzEVT_SFTP)
 BEGIN_EVENT_TABLE(CSftpControlSocket, CControlSocket)
 EVT_COMMAND(wxID_ANY, fzEVT_SFTP, CSftpControlSocket::OnSftpEvent)
 EVT_END_PROCESS(wxID_ANY, CSftpControlSocket::OnTerminate)
-END_EVENT_TABLE();
+END_EVENT_TABLE()
 
 class CSftpInputThread : public wxThreadEx
 {
@@ -64,7 +64,7 @@ public:
 	virtual ~CSftpInputThread()
 	{
 		m_criticalSection.Enter();
-		for (std::list<sftp_message*>::iterator iter = m_sftpMessages.begin(); iter != m_sftpMessages.end(); iter++)
+		for (std::list<sftp_message*>::iterator iter = m_sftpMessages.begin(); iter != m_sftpMessages.end(); ++iter)
 			delete *iter;
 		m_criticalSection.Leave();
 	}
@@ -177,7 +177,7 @@ protected:
 		}
 
 		if (read && buffer[read - 1] == '\r')
-			read--;
+			--read;
 
 		buffer[read] = 0;
 
@@ -303,7 +303,7 @@ protected:
 		}
 loopexit:
 
-		return (ExitCode)Close();
+		return reinterpret_cast<ExitCode>(Close());
 	};
 
 	int Close()
@@ -328,7 +328,7 @@ public:
 		m_deleteFailed = false;
 	}
 
-	virtual ~CSftpDeleteOpData() { }
+	virtual ~CSftpDeleteOpData() {}
 
 	CServerPath path;
 	std::list<wxString> files;
@@ -399,6 +399,7 @@ int CSftpControlSocket::Connect(const CServer &server)
 	delete m_pCSConv;
 	if (server.GetEncodingType() == ENCODING_CUSTOM)
 	{
+		LogMessage(Debug_Info, _T("Using custom encoding: %s"), server.GetCustomEncoding().c_str());
 		m_pCSConv = new wxCSConv(server.GetCustomEncoding());
 		m_useUTF8 = false;
 	}
@@ -408,9 +409,7 @@ int CSftpControlSocket::Connect(const CServer &server)
 		m_useUTF8 = true;
 	}
 
-
-	if (m_pCurrentServer)
-		delete m_pCurrentServer;
+	delete m_pCurrentServer;
 	m_pCurrentServer = new CServer(server);
 
 	CSftpConnectOpData* pData = new CSftpConnectOpData;
@@ -511,7 +510,7 @@ int CSftpControlSocket::ConnectParseResponse(bool successful, const wxString& re
 		return FZ_REPLY_OK;
 	default:
 		LogMessage(__TFILE__, __LINE__, this, Debug_Warning, _T("Unknown op state: %d"), pData->opState);
-        DoClose(FZ_REPLY_INTERNALERROR);
+		DoClose(FZ_REPLY_INTERNALERROR);
 		return FZ_REPLY_ERROR;
 	}
 
@@ -582,7 +581,7 @@ int CSftpControlSocket::ConnectSend()
 		break;
 	default:
 		LogMessage(__TFILE__, __LINE__, this, Debug_Warning, _T("Unknown op state: %d"), pData->opState);
-        DoClose(FZ_REPLY_INTERNALERROR);
+		DoClose(FZ_REPLY_INTERNALERROR);
 		return FZ_REPLY_ERROR;
 	}
 
@@ -602,7 +601,7 @@ void CSftpControlSocket::OnSftpEvent(wxCommandEvent& event)
 
 	std::list<sftp_message*> messages;
 	m_pInputThread->GetMessages(messages);
-	for (std::list<sftp_message*>::iterator iter = messages.begin(); iter != messages.end(); iter++)
+	for (std::list<sftp_message*>::iterator iter = messages.begin(); iter != messages.end(); ++iter)
 	{
 		if (!m_pInputThread)
 		{
@@ -677,7 +676,7 @@ void CSftpControlSocket::OnSftpEvent(wxCommandEvent& event)
 							LogMessage(::Error, _("Server sent an additional login prompt. You need to use the interactive login type."));
 						DoClose(FZ_REPLY_CRITICALERROR | FZ_REPLY_PASSWORDFAILED);
 
-						for (;iter != messages.end(); iter++)
+						for (;iter != messages.end(); ++iter)
 							delete *iter;
 						return;
 					}
@@ -870,9 +869,10 @@ bool CSftpControlSocket::SetAsyncRequestReply(CAsyncRequestNotification *pNotifi
 			CHostKeyNotification *pHostKeyNotification = reinterpret_cast<CHostKeyNotification *>(pNotification);
 			wxString show;
 			if (requestId == reqId_hostkey)
-				show = _("Trust new Hostkey: ");
+				show = _("Trust new Hostkey:");
 			else
-				show = _("Trust changed Hostkey: ");
+				show = _("Trust changed Hostkey:");
+			show += ' ';
 			if (!pHostKeyNotification->m_trust)
 			{
 				Send(_T(""), show + _("No"));
@@ -917,10 +917,11 @@ class CSftpListOpData : public COpData
 public:
 	CSftpListOpData()
 		: COpData(cmd_list)
+		, pParser()
+		, refresh()
+		, fallback_to_current()
+		, mtime_index()
 	{
-		pParser = 0;
-		mtime_index = 0;
-		fallback_to_current = false;
 	}
 
 	virtual ~CSftpListOpData()
@@ -1040,7 +1041,7 @@ int CSftpControlSocket::ListParseResponse(bool successful, const wxString& reply
 		{
 			time_t seconds = 0;
 			bool parsed = true;
-			for (unsigned int i = 0; i < reply.Len(); i++)
+			for (unsigned int i = 0; i < reply.Len(); ++i)
 			{
 				wxChar c = reply[i];
 				if (c < '0' || c > '9')
@@ -1080,7 +1081,7 @@ int CSftpControlSocket::ListParseResponse(bool successful, const wxString& reply
 
 					wxTimeSpan span(0, 0, offset);
 					const int count = pData->directoryListing.GetCount();
-					for (int i = 0; i < count; i++)
+					for (int i = 0; i < count; ++i)
 					{
 						CDirentry& entry = pData->directoryListing[i];
 						if (!entry.has_time())
@@ -1883,7 +1884,7 @@ int CSftpControlSocket::FileTransferSend()
 		}
 
 		wxString quotedFilename = QuoteFilename(pData->remotePath.FormatFilename(pData->remoteFile, !pData->tryAbsolutePath));
-		// Y2K38		
+		// Y2K38
 		time_t ticks = pData->fileTime.GetTicks(); // Already in UTC
 		wxString seconds = wxString::Format(_T("%d"), (int)ticks);
 		if (!Send(_T("chmtime ") + seconds + _T(" ") + WildcardEscape(quotedFilename),
@@ -1943,7 +1944,7 @@ int CSftpControlSocket::FileTransferParseResponse(bool successful, const wxStrin
 		{
 			time_t seconds = 0;
 			bool parsed = true;
-			for (unsigned int i = 0; i < reply.Len(); i++)
+			for (unsigned int i = 0; i < reply.Len(); ++i)
 			{
 				wxChar c = reply[i];
 				if (c < '0' || c > '9')
@@ -2329,7 +2330,7 @@ public:
 	{
 	}
 
-	virtual ~CSftpRemoveDirOpData() { }
+	virtual ~CSftpRemoveDirOpData() {}
 
 	CServerPath path;
 	wxString subDir;
@@ -2411,7 +2412,7 @@ public:
 		m_useAbsolute = false;
 	}
 
-	virtual ~CSftpChmodOpData() { }
+	virtual ~CSftpChmodOpData() {}
 
 	CChmodCommand m_cmd;
 	bool m_useAbsolute;
@@ -2533,7 +2534,7 @@ public:
 		m_useAbsolute = false;
 	}
 
-	virtual ~CSftpRenameOpData() { }
+	virtual ~CSftpRenameOpData() {}
 
 	CRenameCommand m_cmd;
 	bool m_useAbsolute;
@@ -2680,7 +2681,7 @@ wxString CSftpControlSocket::WildcardEscape(const wxString& file)
 
 	wxString escapedFile;
 	escapedFile.Alloc(file.Len());
-	for (unsigned int i = 0; i < file.Len(); i++)
+	for (unsigned int i = 0; i < file.Len(); ++i)
 	{
 		const wxChar& c = file[i];
 		switch (c)
@@ -2765,7 +2766,7 @@ int CSftpControlSocket::ListCheckTimezoneDetection()
 	if (CServerCapabilities::GetCapability(*m_pCurrentServer, timezone_offset) == unknown)
 	{
 		const int count = pData->directoryListing.GetCount();
-		for (int i = 0; i < count; i++)
+		for (int i = 0; i < count; ++i)
 		{
 			if (!pData->directoryListing[i].has_time())
 				continue;
