@@ -53,7 +53,7 @@ union sockaddr_u
 // Apparently it is too hard for the richest company in the
 // world to add this simple function with a service pack...
 
-extern "C" 
+extern "C"
 {
 	typedef int (WINAPI *t_getaddrinfo)(const char *nodename, const char *servname,
 						const struct addrinfo *hints, struct addrinfo **res);
@@ -141,6 +141,8 @@ static int ConvertMSWErrorCode(int error)
 		return EFAULT;
 	case WSAEACCES:
 		return EACCES;
+	case WSAETIMEDOUT:
+		return ETIMEDOUT;
 	default:
 		return error;
 	}
@@ -156,7 +158,7 @@ public:
 		int errors[] = {
 			0
 		};
-		for (int i = 0; errors[i]; i++)
+		for (int i = 0; errors[i]; ++i)
 		{
 #ifdef __WXMSW__
 			int code = ConvertMSWErrorCode(errors[i]);
@@ -179,7 +181,7 @@ CSocketEventDispatcher::CSocketEventDispatcher()
 
 CSocketEventDispatcher::~CSocketEventDispatcher()
 {
-	for (std::list<CSocketEvent*>::iterator iter = m_pending_events.begin(); iter != m_pending_events.end(); iter++)
+	for (std::list<CSocketEvent*>::iterator iter = m_pending_events.begin(); iter != m_pending_events.end(); ++iter)
 		delete *iter;
 }
 
@@ -208,7 +210,7 @@ void CSocketEventDispatcher::RemovePending(const CSocketEventHandler* pHandler)
 	wxCriticalSectionLocker lock(m_sync);
 
 	std::list<CSocketEvent*> keep;
-	for (std::list<CSocketEvent*>::iterator iter = m_pending_events.begin(); iter != m_pending_events.end(); iter++)
+	for (std::list<CSocketEvent*>::iterator iter = m_pending_events.begin(); iter != m_pending_events.end(); ++iter)
 	{
 		if ((*iter)->GetSocketEventHandler() != pHandler)
 		{
@@ -226,7 +228,7 @@ void CSocketEventDispatcher::RemovePending(const CSocketEventSource* pSource)
 	wxCriticalSectionLocker lock(m_sync);
 
 	std::list<CSocketEvent*> keep;
-	for (std::list<CSocketEvent*>::iterator iter = m_pending_events.begin(); iter != m_pending_events.end(); iter++)
+	for (std::list<CSocketEvent*>::iterator iter = m_pending_events.begin(); iter != m_pending_events.end(); ++iter)
 	{
 		if ((*iter)->GetSocketEventSource() != pSource)
 		{
@@ -243,7 +245,7 @@ void CSocketEventDispatcher::UpdatePending(const CSocketEventHandler* pOldHandle
 {
 	wxCriticalSectionLocker lock(m_sync);
 
-	for (std::list<CSocketEvent*>::iterator iter = m_pending_events.begin(); iter != m_pending_events.end(); iter++)
+	for (std::list<CSocketEvent*>::iterator iter = m_pending_events.begin(); iter != m_pending_events.end(); ++iter)
 	{
 		CSocketEvent* evt = *iter;
 		if (evt->GetSocketEventSource() != pOldSource || evt->GetSocketEventHandler() != pOldHandler)
@@ -344,7 +346,7 @@ public:
 		m_triggered = 0;
 		m_threadwait = false;
 
-		for (int i = 0; i < WAIT_EVENTCOUNT; i++)
+		for (int i = 0; i < WAIT_EVENTCOUNT; ++i)
 		{
 			m_triggered_errors[i] = 0;
 		}
@@ -368,16 +370,13 @@ public:
 		if (!already_locked)
 			m_sync.Lock();
 		m_pSocket = pSocket;
-		if (m_pHost)
-		{
-			delete [] m_pHost;
-			m_pHost = 0;
-		}
-		if (m_pPort)
-		{
-			delete [] m_pPort;
-			m_pPort = 0;
-		}
+
+		delete [] m_pHost;
+		m_pHost = 0;
+
+		delete [] m_pPort;
+		m_pPort = 0;
+
 		m_waiting = 0;
 		if (!already_locked)
 			m_sync.Unlock();
@@ -386,10 +385,8 @@ public:
 	int Connect()
 	{
 		wxASSERT(m_pSocket);
-		if (m_pHost)
-			delete [] m_pHost;
-		if (m_pPort)
-			delete [] m_pPort;
+		delete [] m_pHost;
+		delete [] m_pPort;
 
 		const wxWX2MBbuf buf = m_pSocket->m_host.mb_str();
 		if (!buf)
@@ -450,7 +447,7 @@ public:
 	{
 		if (!already_locked)
 			m_sync.Lock();
-			
+
 		if (!m_started || m_finished)
 		{
 			if (!already_locked)
@@ -471,7 +468,12 @@ public:
 		WSASetEvent(m_sync_event);
 #else
 		char tmp = 0;
-		write(m_pipe[1], &tmp, 1);
+
+		int ret;
+		do
+		{
+			ret = write(m_pipe[1], &tmp, 1);
+		} while (ret == -1 && errno == EINTR);
 #endif
 		if (!already_locked)
 			m_sync.Unlock();
@@ -503,7 +505,7 @@ protected:
 
 			return 0;
 		}
-		
+
 #if defined(SO_NOSIGPIPE) && !defined(MSG_NOSIGNAL)
 		// We do not want SIGPIPE if writing to socket.
 		const int value = 1;
@@ -759,7 +761,7 @@ protected:
 	{
 		m_waiting |= wait;
 
-		while (true)
+		for (;;)
 		{
 #ifdef __WXMSW__
 			int wait_events = FD_CLOSE;
@@ -859,11 +861,12 @@ protected:
 			int res = select(max, &readfds, &writefds, 0, 0);
 
 			m_sync.Lock();
-			
+
 			if (res > 0 && FD_ISSET(m_pipe[0], &readfds))
 			{
 				char buffer[100];
-				read(m_pipe[0], buffer, 100);
+				int damn_spurious_warning = read(m_pipe[0], buffer, 100);
+				(void)damn_spurious_warning; // We do not care about return value and this is definitely correct!
 			}
 
 			if (m_quit || !m_pSocket || m_pSocket->m_fd == -1)
@@ -936,6 +939,8 @@ protected:
 			return;
 		if (m_triggered & WAIT_READ)
 		{
+			if (m_pSocket->m_synchronous_read_cb)
+				m_pSocket->m_synchronous_read_cb->cb();
 			CSocketEvent *evt = new CSocketEvent(m_pSocket->m_pEvtHandler, m_pSocket, CSocketEvent::read, m_triggered_errors[1]);
 			CSocketEventDispatcher::Get().SendEvent(evt);
 			m_triggered &= ~WAIT_READ;
@@ -980,7 +985,7 @@ protected:
 	virtual ExitCode Entry()
 	{
 		m_sync.Lock();
-		while (true)
+		for (;;)
 		{
 			if (!IdleLoop())
 			{
@@ -1076,10 +1081,13 @@ protected:
 
 	// Thread waits for instructions
 	bool m_threadwait;
+
+	CCallback* m_synchronous_read_cb;
 };
 
 CSocket::CSocket(CSocketEventHandler* pEvtHandler)
 	: m_pEvtHandler(pEvtHandler)
+	, m_synchronous_read_cb()
 {
 #ifdef ERRORCODETEST
 	CErrorCodeTest test;
@@ -1342,13 +1350,14 @@ static struct Error_table error_table[] =
 	ERRORDECL(WSAEPROTOTYPE, "Protocol not supported on given socket type")
 	ERRORDECL(WSAESOCKTNOSUPPORT, "Socket type not supported for address family")
 	ERRORDECL(WSAEADDRNOTAVAIL, "Cannot assign requested address")
+	ERRORDECL(ERROR_NETNAME_DELETED, "The specified network name is no longer available")
 #endif
 	{ 0, 0, 0 }
 };
 
 wxString CSocket::GetErrorString(int error)
 {
-	for (int i = 0; error_table[i].code; i++)
+	for (int i = 0; error_table[i].code; ++i)
 	{
 		if (error != error_table[i].code)
 			continue;
@@ -1361,7 +1370,7 @@ wxString CSocket::GetErrorString(int error)
 
 wxString CSocket::GetErrorDescription(int error)
 {
-	for (int i = 0; error_table[i].code; i++)
+	for (int i = 0; error_table[i].code; ++i)
 	{
 		if (error != error_table[i].code)
 			continue;
@@ -1792,7 +1801,7 @@ int CSocket::GetLocalPort(int& error)
 
 int CSocket::GetRemotePort(int& error)
 {
-	sockaddr_u addr;		
+	sockaddr_u addr;
 	socklen_t addr_len = sizeof(addr);
 	error = getpeername(m_fd, &addr.sockaddr, &addr_len);
 	if (error)
@@ -1831,7 +1840,7 @@ CSocket* CSocket::Accept(int &error)
 #endif
 		return 0;
 	}
-	
+
 #if defined(SO_NOSIGPIPE) && !defined(MSG_NOSIGNAL)
 	// We do not want SIGPIPE if writing to socket.
 	const int value = 1;
@@ -1956,3 +1965,14 @@ int CSocket::DoSetBufferSizes(int fd, int size_read, int size_write)
 
 	return 0;
 }
+
+void CSocket::SetSynchronousReadCallback(CCallback* cb)
+{
+	if (m_pSocketThread)
+		m_pSocketThread->m_sync.Lock();
+
+	m_synchronous_read_cb = cb;
+
+	if (m_pSocketThread)
+		m_pSocketThread->m_sync.Unlock();
+}
