@@ -11,7 +11,7 @@
 
 BEGIN_EVENT_TABLE(CTransferSocket, wxEvtHandler)
 	EVT_IOTHREAD(wxID_ANY, CTransferSocket::OnIOThreadEvent)
-END_EVENT_TABLE();
+END_EVENT_TABLE()
 
 CTransferSocket::CTransferSocket(CFileZillaEnginePrivate *pEngine, CFtpControlSocket *pControlSocket, enum TransferMode transferMode)
 {
@@ -55,7 +55,7 @@ CTransferSocket::~CTransferSocket()
 	delete m_pProxyBackend;
 	if (m_pTlsSocket)
 		delete m_pTlsSocket;
-	else if (m_pBackend)
+	else
 		delete m_pBackend;
 	delete m_pSocketServer;
 	m_pSocketServer = 0;
@@ -66,7 +66,7 @@ CTransferSocket::~CTransferSocket()
 	{
 		if (m_transferMode == upload || m_transferMode == download)
 		{
-			CFtpFileTransferOpData *pData = static_cast<CFtpFileTransferOpData *>(static_cast<CRawTransferOpData *>(m_pControlSocket->m_pCurOpData)->pOldData);;
+			CFtpFileTransferOpData *pData = static_cast<CFtpFileTransferOpData *>(static_cast<CRawTransferOpData *>(m_pControlSocket->m_pCurOpData)->pOldData);
 			if (pData && pData->pIOThread)
 			{
 				if (m_transferMode == download)
@@ -83,9 +83,8 @@ wxString CTransferSocket::SetupActiveTransfer(const wxString& ip)
 	delete m_pSocket;
 	m_pSocket = 0;
 	delete m_pSocketServer;
-	m_pSocketServer = 0;
-
 	m_pSocketServer = CreateSocketServer();
+
 	if (!m_pSocketServer)
 	{
 		m_pControlSocket->LogMessage(::Debug_Warning, _T("CreateSocketServer failed"));
@@ -166,7 +165,16 @@ void CTransferSocket::OnSocketEvent(CSocketEvent &event)
 	switch (event.GetType())
 	{
 	case CSocketEvent::connection:
-		OnConnect();
+		if (event.GetError())
+		{
+			if (!m_transferEndReason)
+			{
+				m_pControlSocket->LogMessage(::Error, _("The data connection could not be established: %s"), CSocket::GetErrorDescription(event.GetError()).c_str());
+				TransferEnd(transfer_failure);
+			}
+		}
+		else
+			OnConnect();
 		break;
 	case CSocketEvent::read:
 		OnReceive();
@@ -266,7 +274,7 @@ void CTransferSocket::OnReceive()
 
 	if (m_transferMode == list)
 	{
-		while (true)
+		for (;;)
 		{
 			char *pBuffer = new char[4096];
 			int error;
@@ -311,7 +319,7 @@ void CTransferSocket::OnReceive()
 	}
 	else if (m_transferMode == download)
 	{
-		while (true)
+		for (;;)
 		{
 			if (!CheckGetNextWriteBuffer())
 				return;
@@ -355,7 +363,7 @@ void CTransferSocket::OnReceive()
 	}
 	else if (m_transferMode == resumetest)
 	{
-		while (true)
+		for (;;)
 		{
 			char buffer[2];
 			int error;
@@ -406,7 +414,10 @@ void CTransferSocket::OnReceive()
 void CTransferSocket::OnSend()
 {
 	if (!m_pBackend)
+	{
+		m_pControlSocket->LogMessage(::Debug_Verbose, _T("OnSend called without backend. Ignoring event."));
 		return;
+	}
 
 	if (!m_bActive)
 	{
@@ -539,7 +550,6 @@ bool CTransferSocket::SetupPassiveTransfer(wxString host, int port)
 {
 	// Void all previous attempts to createt a socket
 	delete m_pSocket;
-	m_pSocket = 0;
 	delete m_pSocketServer;
 	m_pSocketServer = 0;
 
@@ -587,7 +597,7 @@ void CTransferSocket::SetActive()
 		return;
 	if (m_transferMode == download || m_transferMode == upload)
 	{
-		CFtpFileTransferOpData *pData = static_cast<CFtpFileTransferOpData *>(static_cast<CRawTransferOpData *>(m_pControlSocket->m_pCurOpData)->pOldData);;
+		CFtpFileTransferOpData *pData = static_cast<CFtpFileTransferOpData *>(static_cast<CRawTransferOpData *>(m_pControlSocket->m_pCurOpData)->pOldData);
 		if (pData && pData->pIOThread)
 			pData->pIOThread->SetEventHandler(this);
 	}
@@ -595,7 +605,7 @@ void CTransferSocket::SetActive()
 	m_bActive = true;
 	if (!m_pSocket)
 		return;
-	
+
 	if (m_pSocket->GetState() == CSocket::connected || m_pSocket->GetState() == CSocket::closing)
 		TriggerPostponedEvents();
 }
@@ -611,23 +621,20 @@ void CTransferSocket::TransferEnd(enum TransferEndReason reason)
 	delete m_pSocketServer;
 	m_pSocketServer = 0;
 
-	if (m_pProxyBackend)
-	{
-		delete m_pProxyBackend;
-		m_pProxyBackend = 0;
-	}
+	delete m_pProxyBackend;
+	m_pProxyBackend = 0;
+
 	if (m_pTlsSocket)
 	{
 		if (m_pBackend == m_pTlsSocket)
 			m_pBackend = 0;
-        delete m_pTlsSocket;
+		delete m_pTlsSocket;
 		m_pTlsSocket = 0;
 	}
-	if (m_pBackend)
-	{
-		delete m_pBackend;
-		m_pBackend = 0;
-	}
+
+	delete m_pBackend;
+	m_pBackend = 0;
+
 	delete m_pSocket;
 	m_pSocket = 0;
 
@@ -699,7 +706,7 @@ CSocket* CTransferSocket::CreateSocketServer()
 
 bool CTransferSocket::CheckGetNextWriteBuffer()
 {
-	CFtpFileTransferOpData *pData = static_cast<CFtpFileTransferOpData *>(static_cast<CRawTransferOpData *>(m_pControlSocket->m_pCurOpData)->pOldData);;
+	CFtpFileTransferOpData *pData = static_cast<CFtpFileTransferOpData *>(static_cast<CRawTransferOpData *>(m_pControlSocket->m_pCurOpData)->pOldData);
 	if (!m_transferBufferLen)
 	{
 		int res = pData->pIOThread->GetNextWriteBuffer(&m_pTransferBuffer);
@@ -725,7 +732,7 @@ bool CTransferSocket::CheckGetNextWriteBuffer()
 
 bool CTransferSocket::CheckGetNextReadBuffer()
 {
-	CFtpFileTransferOpData *pData = static_cast<CFtpFileTransferOpData *>(static_cast<CRawTransferOpData *>(m_pControlSocket->m_pCurOpData)->pOldData);;
+	CFtpFileTransferOpData *pData = static_cast<CFtpFileTransferOpData *>(static_cast<CRawTransferOpData *>(m_pControlSocket->m_pCurOpData)->pOldData);
 	if (!m_transferBufferLen)
 	{
 		int res = pData->pIOThread->GetNextReadBuffer(&m_pTransferBuffer);
@@ -742,7 +749,7 @@ bool CTransferSocket::CheckGetNextReadBuffer()
 			if (m_pTlsSocket)
 			{
 				m_shutdown = true;
-				
+
 				int error = m_pTlsSocket->Shutdown();
 				if (error != 0)
 				{
