@@ -1,7 +1,8 @@
-#include "FileZilla.h"
+#include <filezilla.h>
 #include "bookmarks_dialog.h"
 #include "sitemanager.h"
 #include "ipcmutex.h"
+#include "themeprovider.h"
 #include "xmlfunctions.h"
 
 BEGIN_EVENT_TABLE(CNewBookmarkDialog, wxDialogEx)
@@ -23,7 +24,9 @@ EVT_TREE_END_LABEL_EDIT(XRCID("ID_TREE"), CBookmarksDialog::OnEndLabelEdit)
 END_EVENT_TABLE()
 
 CNewBookmarkDialog::CNewBookmarkDialog(wxWindow* parent, wxString& site_path, const CServer* server)
-: m_parent(parent), m_site_path(site_path), m_server(server)
+	: m_parent(parent)
+	, m_site_path(site_path)
+	, m_server(server)
 {
 }
 
@@ -35,7 +38,7 @@ int CNewBookmarkDialog::ShowModal(const wxString &local_path, const CServerPath
 	XRCCTRL(*this, "ID_LOCALPATH", wxTextCtrl)->ChangeValue(local_path);
 	if (!remote_path.IsEmpty())
 		XRCCTRL(*this, "ID_REMOTEPATH", wxTextCtrl)->ChangeValue(remote_path.GetPath());
-	
+
 	if (!m_server)
 		XRCCTRL(*this, "ID_TYPE_SITE", wxRadioButton)->Enable(false);
 
@@ -98,7 +101,7 @@ void CNewBookmarkDialog::OnOK(wxCommandEvent& event)
 				return;
 			}
 		}
-		for (std::list<wxString>::const_iterator iter = bookmarks.begin(); iter != bookmarks.end(); iter++)
+		for (std::list<wxString>::const_iterator iter = bookmarks.begin(); iter != bookmarks.end(); ++iter)
 		{
 			if (*iter == name)
 			{
@@ -150,7 +153,10 @@ public:
 };
 
 CBookmarksDialog::CBookmarksDialog(wxWindow* parent, wxString& site_path, const CServer* server)
-: m_parent(parent), m_site_path(site_path), m_server(server)
+	: m_parent(parent)
+	, m_site_path(site_path)
+	, m_server(server)
+	, m_pTree()
 {
 }
 
@@ -212,7 +218,7 @@ void CBookmarksDialog::LoadSiteSpecificBookmarks()
 	if (!CSiteManager::GetBookmarks(m_site_path, bookmarks))
 		return;
 
-	for (std::list<wxString>::const_iterator iter = bookmarks.begin(); iter != bookmarks.end(); iter++)
+	for (std::list<wxString>::const_iterator iter = bookmarks.begin(); iter != bookmarks.end(); ++iter)
 	{
 		wxString path = *iter;
 		path.Replace(_T("\\"), _T("\\\\"));
@@ -239,10 +245,12 @@ int CBookmarksDialog::ShowModal(const wxString &local_path, const CServerPath &r
 	m_pTree = XRCCTRL(*this, "ID_TREE", wxTreeCtrl);
 	if (!m_pTree)
 		return false;
-	wxImageList* pImageList = new wxImageList(16, 16);
 
-	pImageList->Add(wxArtProvider::GetBitmap(_T("ART_FOLDER"),  wxART_OTHER, wxSize(16, 16)));
-	pImageList->Add(wxArtProvider::GetBitmap(_T("ART_BOOKMARK"),  wxART_OTHER, wxSize(16, 16)));
+	wxSize s = CThemeProvider::GetIconSize(iconSizeSmall);
+	wxImageList* pImageList = new wxImageList(s.x, s.y);
+
+	pImageList->Add(wxArtProvider::GetBitmap(_T("ART_FOLDER"), wxART_OTHER, CThemeProvider::GetIconSize(iconSizeSmall)));
+	pImageList->Add(wxArtProvider::GetBitmap(_T("ART_BOOKMARK"), wxART_OTHER, CThemeProvider::GetIconSize(iconSizeSmall)));
 
 	m_pTree->AssignImageList(pImageList);
 
@@ -273,6 +281,8 @@ int CBookmarksDialog::ShowModal(const wxString &local_path, const CServerPath &r
 	SetMinSize(GetSizer()->GetMinSize() + size - clientSize);
 	SetClientSize(minSize);
 
+	m_pTree->SelectItem(m_bookmarks_global);
+
 	return wxDialogEx::ShowModal();
 }
 
@@ -304,7 +314,7 @@ void CBookmarksDialog::SaveGlobalBookmarks()
 		CBookmarkItemData *data = (CBookmarkItemData *)m_pTree->GetItemData(child);
 		wxASSERT(data);
 
-		TiXmlElement *pBookmark = pDocument->InsertEndChild(TiXmlElement("Bookmark"))->ToElement();
+		TiXmlElement *pBookmark = pDocument->LinkEndChild(new TiXmlElement("Bookmark"))->ToElement();
 		AddTextElement(pBookmark, "Name", m_pTree->GetItemText(child));
 		if (!data->m_local_dir.empty())
 			AddTextElement(pBookmark, "LocalDir", data->m_local_dir);
@@ -358,7 +368,7 @@ void CBookmarksDialog::OnBrowse(wxCommandEvent& event)
 	wxTreeItemId item = m_pTree->GetSelection();
 	if (!item)
 		return;
-	
+
 	CBookmarkItemData *data = (CBookmarkItemData *)m_pTree->GetItemData(item);
 	if (!data)
 		return;
@@ -393,7 +403,7 @@ bool CBookmarksDialog::Verify()
 	wxTreeItemId item = m_pTree->GetSelection();
 	if (!item)
 		return true;
-	
+
 	CBookmarkItemData *data = (CBookmarkItemData *)m_pTree->GetItemData(item);
 	if (!data)
 		return true;
@@ -452,7 +462,7 @@ void CBookmarksDialog::UpdateBookmark()
 	wxTreeItemId item = m_pTree->GetSelection();
 	if (!item)
 		return;
-	
+
 	CBookmarkItemData *data = (CBookmarkItemData *)m_pTree->GetItemData(item);
 	if (!data)
 		return;
@@ -489,7 +499,7 @@ void CBookmarksDialog::DisplayBookmark()
 		XRCCTRL(*this, "ID_NOTEBOOK", wxNotebook)->Enable(false);
 		return;
 	}
-	
+
 	CBookmarkItemData *data = (CBookmarkItemData *)m_pTree->GetItemData(item);
 	if (!data)
 	{
@@ -546,7 +556,7 @@ void CBookmarksDialog::OnNewBookmark(wxCommandEvent& event)
 
 	wxString newName = _("New bookmark");
 	int index = 2;
-	while (true)
+	for (;;)
 	{
 		wxTreeItemId child;
 		wxTreeItemIdValue cookie;
@@ -617,7 +627,7 @@ void CBookmarksDialog::OnCopy(wxCommandEvent& event)
 	const wxString name = m_pTree->GetItemText(item);
 	wxString newName = wxString::Format(_("Copy of %s"), name.c_str());
 	int index = 2;
-	while (true)
+	for (;;)
 	{
 		wxTreeItemId child;
 		wxTreeItemIdValue cookie;
@@ -767,7 +777,7 @@ bool CBookmarksDialog::GetBookmark(const wxString &name, wxString &local_dir, CS
 	for (TiXmlElement *pBookmark = pDocument->FirstChildElement("Bookmark"); pBookmark; pBookmark = pBookmark->NextSiblingElement("Bookmark"))
 	{
 		wxString remote_dir_raw;
-	
+
 		if (name != GetTextElement(pBookmark, "Name"))
 			continue;
 
@@ -813,19 +823,27 @@ bool CBookmarksDialog::AddBookmark(const wxString &name, const wxString &local_d
 		return false;
 	}
 
+	TiXmlElement *pInsertBefore = 0;
 	TiXmlElement *pBookmark;
 	for (pBookmark = pDocument->FirstChildElement("Bookmark"); pBookmark; pBookmark = pBookmark->NextSiblingElement("Bookmark"))
 	{
 		wxString remote_dir_raw;
-	
-		if (!name.CmpNoCase(GetTextElement(pBookmark, "Name")))
+
+		wxString old_name = GetTextElement(pBookmark, "Name");
+
+		if (!name.CmpNoCase(old_name))
 		{
 			wxMessageBox(_("Name of bookmark already exists."), _("New bookmark"), wxICON_EXCLAMATION);
 			return false;
 		}
+		if (name < old_name && !pInsertBefore)
+			pInsertBefore = pBookmark;
 	}
 
-	pBookmark = pDocument->InsertEndChild(TiXmlElement("Bookmark"))->ToElement();
+	if (pInsertBefore)
+		pBookmark = pDocument->InsertBeforeChild(pInsertBefore, TiXmlElement("Bookmark"))->ToElement();
+	else
+		pBookmark = pDocument->LinkEndChild(new TiXmlElement("Bookmark"))->ToElement();
 	AddTextElement(pBookmark, "Name", name);
 	if (!local_dir.empty())
 		AddTextElement(pBookmark, "LocalDir", local_dir);
