@@ -11,6 +11,8 @@ enum t_filterType
 	filter_attributes = 0x04,
 	filter_permissions = 0x08,
 	filter_path = 0x10,
+	filter_date = 0x20,
+	filter_time = 0x40,
 #ifdef __WXMSW__
 	filter_meta = filter_attributes,
 	filter_foreign = filter_permissions,
@@ -27,8 +29,10 @@ public:
 
 	enum t_filterType type;
 	int condition;
-	wxString strValue;
-	wxLongLong value;
+
+	wxString strValue; // All other types
+	wxLongLong value; // If type is size
+	wxDateTime date; // If type is date
 	bool matchCase;
 	CSharedPointer<const wxRegEx> pRegEx;
 };
@@ -66,15 +70,16 @@ public:
 	std::vector<bool> remote;
 };
 
+class TiXmlElement;
 class CFilterManager
 {
 public:
 	CFilterManager();
 
 	// Note: Under non-windows, attributes are permissions
-	bool FilenameFiltered(const wxString& name, const wxString& path, bool dir, wxLongLong size, bool local, int attributes) const;
-	bool FilenameFiltered(const std::list<CFilter> &filters, const wxString& name, const wxString& path, bool dir, wxLongLong size, bool local, int attributes) const;
-	static bool FilenameFilteredByFilter(const CFilter& filter, const wxString& name, const wxString& path, bool dir, wxLongLong size, int attributes);
+	bool FilenameFiltered(const wxString& name, const wxString& path, bool dir, wxLongLong size, bool local, int attributes, const wxDateTime* date) const;
+	bool FilenameFiltered(const std::list<CFilter> &filters, const wxString& name, const wxString& path, bool dir, wxLongLong size, bool local, int attributes, const wxDateTime* date) const;
+	static bool FilenameFilteredByFilter(const CFilter& filter, const wxString& name, const wxString& path, bool dir, wxLongLong size, int attributes, const wxDateTime* date);
 	static bool HasActiveFilters(bool ignore_disabled = false);
 
 	bool HasSameLocalAndRemoteFilters() const;
@@ -85,6 +90,8 @@ public:
 
 	static bool CompileRegexes(CFilter& filter);
 
+	static bool LoadFilter(TiXmlElement* pElement, CFilter& filter);
+
 protected:
 	static bool CompileRegexes();
 
@@ -104,10 +111,12 @@ class CFilterDialog : public wxDialogEx, public CFilterManager
 {
 public:
 	CFilterDialog();
-	virtual ~CFilterDialog() { }
+	virtual ~CFilterDialog() {}
 
 	bool Create(CMainFrame* parent);
 
+	static void SaveFilter(TiXmlElement* pElement, const CFilter& filter);
+
 protected:
 
 	void SaveFilters();
@@ -116,7 +125,7 @@ protected:
 
 	void SetCtrlState();
 
-	DECLARE_EVENT_TABLE();
+	DECLARE_EVENT_TABLE()
 	void OnOK(wxCommandEvent& event);
 	void OnCancel(wxCommandEvent& event);
 	void OnApply(wxCommandEvent& event);
