@@ -1,6 +1,8 @@
-#include "FileZilla.h"
+#include <filezilla.h>
 #include "filteredit.h"
 #include "customheightlistctrl.h"
+#include "window_state_manager.h"
+#include "Options.h"
 
 BEGIN_EVENT_TABLE(CFilterEditDialog, CFilterConditionsDialog)
 EVT_BUTTON(XRCID("wxID_OK"), CFilterEditDialog::OnOK)
@@ -10,7 +12,23 @@ EVT_BUTTON(XRCID("ID_DELETE"), CFilterEditDialog::OnDelete)
 EVT_BUTTON(XRCID("ID_RENAME"), CFilterEditDialog::OnRename)
 EVT_BUTTON(XRCID("ID_COPY"), CFilterEditDialog::OnCopy)
 EVT_LISTBOX(XRCID("ID_FILTERS"), CFilterEditDialog::OnFilterSelect)
-END_EVENT_TABLE();
+END_EVENT_TABLE()
+
+CFilterEditDialog::CFilterEditDialog()
+	: m_pFilterListCtrl(0)
+	, m_currentSelection(-1)
+	, m_pWindowStateManager(0)
+{
+}
+
+CFilterEditDialog::~CFilterEditDialog()
+{
+	if (m_pWindowStateManager)
+	{
+		m_pWindowStateManager->Remember(OPTION_FILTEREDIT_SIZE);
+		delete m_pWindowStateManager;
+	}
+}
 
 void CFilterEditDialog::OnOK(wxCommandEvent& event)
 {
@@ -42,7 +60,7 @@ void CFilterEditDialog::OnCancel(wxCommandEvent& event)
 bool CFilterEditDialog::Create(wxWindow* parent, const std::vector<CFilter>& filters, const std::vector<CFilterSet>& filterSets)
 {
 	bool has_foreign_type = false;
-	for (std::vector<CFilter>::const_iterator iter = filters.begin(); iter != filters.end(); iter++)
+	for (std::vector<CFilter>::const_iterator iter = filters.begin(); iter != filters.end(); ++iter)
 	{
 		const CFilter& filter = *iter;
 		if (!filter.HasConditionOfType(filter_foreign))
@@ -55,12 +73,12 @@ bool CFilterEditDialog::Create(wxWindow* parent, const std::vector<CFilter>& fil
 	if (!Load(parent, _T("ID_EDITFILTER")))
 		return false;
 
-	int conditions = filter_name | filter_size | filter_path | filter_meta;
+	int conditions = filter_name | filter_size | filter_path | filter_meta | filter_date;
 	if (has_foreign_type)
 		conditions |= filter_foreign;
 	if (!CreateListControl(conditions))
 		return false;
-	
+
 	m_pFilterListCtrl = XRCCTRL(*this, "ID_FILTERS", wxListBox);
 	if (!m_pFilterListCtrl)
 		return false;
@@ -68,10 +86,13 @@ bool CFilterEditDialog::Create(wxWindow* parent, const std::vector<CFilter>& fil
 
 	m_filters = filters;
 	m_filterSets = filterSets;
-	for (std::vector<CFilter>::const_iterator iter = filters.begin(); iter != filters.end(); iter++)
+	for (std::vector<CFilter>::const_iterator iter = filters.begin(); iter != filters.end(); ++iter)
 		m_pFilterListCtrl->Append(iter->name);
+
+	m_pWindowStateManager = new CWindowStateManager(this);
+	m_pWindowStateManager->Restore(OPTION_FILTEREDIT_SIZE, wxSize(750, 500));
+
 	Layout();
-	Fit();
 
 	SetCtrlState(false);
 
@@ -125,7 +146,7 @@ void CFilterEditDialog::OnNew(wxCommandEvent& event)
 
 	if (m_pFilterListCtrl->FindString(newName) != wxNOT_FOUND)
 	{
-		wxMessageBox(_("The entered filter name already exists."), _("Duplicate filter name"), wxICON_ERROR, this);
+		wxMessageBox(_("The entered filter name already exists, please choose a different name."), _("Filter name already exists"), wxICON_ERROR, this);
 		return;
 	}
 
@@ -134,7 +155,7 @@ void CFilterEditDialog::OnNew(wxCommandEvent& event)
 
 	m_filters.push_back(filter);
 
-	for (std::vector<CFilterSet>::iterator iter = m_filterSets.begin(); iter != m_filterSets.end(); iter++)
+	for (std::vector<CFilterSet>::iterator iter = m_filterSets.begin(); iter != m_filterSets.end(); ++iter)
 	{
 		CFilterSet& set = *iter;
 		set.local.push_back(false);
@@ -158,7 +179,7 @@ void CFilterEditDialog::OnDelete(wxCommandEvent& event)
 	m_filters.erase(m_filters.begin() + item);
 
 	// Remote filter from all filter sets
-	for (std::vector<CFilterSet>::iterator iter = m_filterSets.begin(); iter != m_filterSets.end(); iter++)
+	for (std::vector<CFilterSet>::iterator iter = m_filterSets.begin(); iter != m_filterSets.end(); ++iter)
 	{
 		CFilterSet& set = *iter;
 		set.local.erase(set.local.begin() + item);
@@ -193,7 +214,7 @@ void CFilterEditDialog::OnRename(wxCommandEvent& event)
 
 	if (m_pFilterListCtrl->FindString(newName) != wxNOT_FOUND)
 	{
-		wxMessageBox(_("The entered filter name already exists."), _("Duplicate filter name"), wxICON_ERROR, this);
+		wxMessageBox(_("The entered filter name already exists, please choose a different name."), _("Filter name already exists"), wxICON_ERROR, this);
 		return;
 	}
 
@@ -232,7 +253,7 @@ void CFilterEditDialog::OnCopy(wxCommandEvent& event)
 
 	if (m_pFilterListCtrl->FindString(newName) != wxNOT_FOUND)
 	{
-		wxMessageBox(_("The entered filter name already exists."), _("Duplicate filter name"), wxICON_ERROR, this);
+		wxMessageBox(_("The entered filter name already exists, please choose a different name."), _("Filter name already exists"), wxICON_ERROR, this);
 		return;
 	}
 
@@ -240,7 +261,7 @@ void CFilterEditDialog::OnCopy(wxCommandEvent& event)
 
 	m_filters.push_back(filter);
 
-	for (std::vector<CFilterSet>::iterator iter = m_filterSets.begin(); iter != m_filterSets.end(); iter++)
+	for (std::vector<CFilterSet>::iterator iter = m_filterSets.begin(); iter != m_filterSets.end(); ++iter)
 	{
 		CFilterSet& set = *iter;
 		set.local.push_back(false);
