@@ -1,10 +1,9 @@
-#include "FileZilla.h"
+#include <filezilla.h>
 #include "import.h"
 #include "xmlfunctions.h"
 #include "ipcmutex.h"
 #include "Options.h"
 #include "queue.h"
-#include "filezillaapp.h"
 
 CImportDialog::CImportDialog(wxWindow* parent, CQueueView* pQueueView)
 	: m_parent(parent), m_pQueueView(pQueueView)
@@ -13,32 +12,35 @@ CImportDialog::CImportDialog(wxWindow* parent, CQueueView* pQueueView)
 
 void CImportDialog::Show()
 {
-	wxFileDialog dlg(m_parent, _("Select file to import settings from"), _T(""), 
-					_T("FileZilla.xml"), _T("XML files (*.xml)|*.xml"), 
+	wxFileDialog dlg(m_parent, _("Select file to import settings from"), _T(""),
+					_T("FileZilla.xml"), _T("XML files (*.xml)|*.xml"),
 					wxFD_OPEN | wxFD_FILE_MUST_EXIST);
+	dlg.CenterOnParent();
 
 	if (dlg.ShowModal() != wxID_OK)
 		return;
 
 	wxFileName fn(dlg.GetPath());
 	const wxString& path = fn.GetPath();
-	const wxString& settings = wxGetApp().GetSettingsDir();
+	const wxString& settings(COptions::Get()->GetOption(OPTION_DEFAULT_SETTINGSDIR));
 	if (path == settings)
 	{
 		wxMessageBox(_("You cannot import settings from FileZilla's own settings directory."), _("Error importing"), wxICON_ERROR, m_parent);
 		return;
 	}
 
-	TiXmlDocument xmlDocument;
-	xmlDocument.SetCondenseWhiteSpace(false);
-	if (!xmlDocument.LoadFile(dlg.GetPath().mb_str()))
+	TiXmlDocument* xmlDocument = new TiXmlDocument();
+	xmlDocument->SetCondenseWhiteSpace(false);
+
+	if (!LoadXmlDocument(xmlDocument, dlg.GetPath()))
 	{
+		delete xmlDocument;
 		wxMessageBox(_("Cannot load file, not a valid XML file."), _("Error importing"), wxICON_ERROR, m_parent);
 		return;
 	}
 
-	TiXmlElement* fz3Root = xmlDocument.FirstChildElement("FileZilla3");
-	TiXmlElement* fz2Root = xmlDocument.FirstChildElement("FileZilla");
+	TiXmlElement* fz3Root = xmlDocument->FirstChildElement("FileZilla3");
+	TiXmlElement* fz2Root = xmlDocument->FirstChildElement("FileZilla");
 
 	if (fz3Root)
 	{
@@ -58,7 +60,10 @@ void CImportDialog::Show()
 			Fit();
 
 			if (ShowModal() != wxID_OK)
+			{
+				delete xmlDocument;
 				return;
+			}
 
 			if (queue && XRCCTRL(*this, "ID_QUEUE", wxCheckBox)->IsChecked())
 			{
@@ -75,9 +80,10 @@ void CImportDialog::Show()
 				COptions::Get()->Import(fz3Root->FirstChildElement("Settings"));
 				wxMessageBox(_("The settings have been imported. You have to restart FileZilla for all settings to have effect."), _("Import successful"), wxOK, this);
 			}
-			
+
 			wxMessageBox(_("The selected categories have been imported."), _("Import successful"), wxOK, this);
 
+			delete xmlDocument;
 			return;
 		}
 	}
@@ -88,14 +94,17 @@ void CImportDialog::Show()
 		{
 			int res = wxMessageBox(_("The file you have selected contains site manager data from a previous version of FileZilla.\nDue to differences in the storage format, only host, port, username and password will be imported.\nContinue with the import?"),
 				_("Import data from older version"), wxICON_QUESTION | wxYES_NO);
-			
+
 			if (res == wxYES)
 				ImportLegacySites(fz2Root->FirstChildElement("Sites"));
 
+			delete xmlDocument;
 			return;
 		}
 	}
 
+	delete xmlDocument;
+
 	wxMessageBox(_("File does not contain any importable data."), _("Error importing"), wxICON_ERROR, m_parent);
 }
 
@@ -115,7 +124,7 @@ bool CImportDialog::ImportLegacySites(TiXmlElement* pSites)
 
 	TiXmlElement* pCurrentSites = pDocument->FirstChildElement("Servers");
 	if (!pCurrentSites)
-		pCurrentSites = pDocument->InsertEndChild(TiXmlElement("Servers"))->ToElement();
+		pCurrentSites = pDocument->LinkEndChild(new TiXmlElement("Servers"))->ToElement();
 
 	if (!ImportLegacySites(pSites, pCurrentSites))
 		return false;
@@ -160,7 +169,7 @@ bool CImportDialog::ImportLegacySites(TiXmlElement* pSitesToImport, TiXmlElement
 		{
 			newName = wxString::Format(_T("%s %d"), name.c_str(), i++);
 		}
-		
+
 		ImportLegacySites(pImportFolder, pFolder);
 	}
 
@@ -225,7 +234,7 @@ bool CImportDialog::ImportLegacySites(TiXmlElement* pSitesToImport, TiXmlElement
 			newName = wxString::Format(_T("%s %d"), name.c_str(), i++);
 		}
 
-		TiXmlElement* pServer = pExistingSites->InsertEndChild(TiXmlElement("Server"))->ToElement();
+		TiXmlElement* pServer = pExistingSites->LinkEndChild(new TiXmlElement("Server"))->ToElement();
 		AddTextElement(pServer, newName);
 
 		AddTextElement(pServer, "Host", host);
@@ -246,12 +255,16 @@ bool CImportDialog::HasEntryWithName(TiXmlElement* pElement, const wxString& nam
 	for (pChild = pElement->FirstChildElement("Server"); pChild; pChild = pChild->NextSiblingElement("Server"))
 	{
 		wxString childName = GetTextElement(pChild);
+		childName.Trim(true);
+		childName.Trim(false);
 		if (!name.CmpNoCase(childName))
 			return true;
 	}
 	for (pChild = pElement->FirstChildElement("Folder"); pChild; pChild = pChild->NextSiblingElement("Folder"))
 	{
 		wxString childName = GetTextElement(pChild);
+		childName.Trim(true);
+		childName.Trim(false);
 		if (!name.CmpNoCase(childName))
 			return true;
 	}
@@ -265,6 +278,8 @@ TiXmlElement* CImportDialog::GetFolderWithName(TiXmlElement* pElement, const wxS
 	for (pChild = pElement->FirstChildElement("Server"); pChild; pChild = pChild->NextSiblingElement("Server"))
 	{
 		wxString childName = GetTextElement(pChild);
+		childName.Trim(true);
+		childName.Trim(false);
 		if (!name.CmpNoCase(childName))
 			return 0;
 	}
@@ -272,11 +287,13 @@ TiXmlElement* CImportDialog::GetFolderWithName(TiXmlElement* pElement, const wxS
 	for (pChild = pElement->FirstChildElement("Folder"); pChild; pChild = pChild->NextSiblingElement("Folder"))
 	{
 		wxString childName = GetTextElement(pChild);
+		childName.Trim(true);
+		childName.Trim(false);
 		if (!name.CmpNoCase(childName))
 			return pChild;
 	}
 
-	pChild = pElement->InsertEndChild(TiXmlElement("Folder"))->ToElement();
+	pChild = pElement->LinkEndChild(new TiXmlElement("Folder"))->ToElement();
 	AddTextElement(pChild, name);
 
 	return pChild;
@@ -298,7 +315,7 @@ bool CImportDialog::ImportSites(TiXmlElement* pSites)
 
 	TiXmlElement* pCurrentSites = pDocument->FirstChildElement("Servers");
 	if (!pCurrentSites)
-		pCurrentSites = pDocument->InsertEndChild(TiXmlElement("Servers"))->ToElement();
+		pCurrentSites = pDocument->LinkEndChild(new TiXmlElement("Servers"))->ToElement();
 
 	if (!ImportSites(pSites, pCurrentSites))
 		return false;
@@ -311,6 +328,8 @@ bool CImportDialog::ImportSites(TiXmlElement* pSitesToImport, TiXmlElement* pExi
 	for (TiXmlElement* pImportFolder = pSitesToImport->FirstChildElement("Folder"); pImportFolder; pImportFolder = pImportFolder->NextSiblingElement("Folder"))
 	{
 		wxString name = GetTextElement(pImportFolder);
+		name.Trim(true);
+		name.Trim(false);
 		if (name == _T(""))
 			continue;
 
@@ -321,13 +340,15 @@ bool CImportDialog::ImportSites(TiXmlElement* pSitesToImport, TiXmlElement* pExi
 		{
 			newName = wxString::Format(_T("%s %d"), name.c_str(), i++);
 		}
-		
+
 		ImportSites(pImportFolder, pFolder);
 	}
 
 	for (TiXmlElement* pImportSite = pSitesToImport->FirstChildElement("Server"); pImportSite; pImportSite = pImportSite->NextSiblingElement("Server"))
 	{
 		wxString name = GetTextElement(pImportSite);
+		name.Trim(true);
+		name.Trim(false);
 		if (name == _T(""))
 			continue;
 
