@@ -1,7 +1,10 @@
 #ifndef __LED_H__
 #define __LED_H__
 
-class CFileZillaEngine;
+#include "wx/event.h"
+
+DECLARE_EVENT_TYPE(fzEVT_UPDATE_LED_TOOLTIP, -1)
+
 class CLed : public wxWindow
 {
 public:
@@ -10,8 +13,6 @@ public:
 
 	void Ping();
 
-	void SetEngine(CFileZillaEngine* pEngine);
-
 protected:
 	void Set();
 	void Unset();
@@ -19,8 +20,6 @@ protected:
 	int m_index;
 	int m_ledState;
 
-	CFileZillaEngine* m_pEngine;
-
 	wxBitmap m_leds[2];
 	bool m_loaded;
 
@@ -29,6 +28,7 @@ protected:
 	DECLARE_EVENT_TABLE()
 	void OnPaint(wxPaintEvent& event);
 	void OnTimer(wxTimerEvent& event);
+	void OnEnterWindow(wxMouseEvent& event);
 #ifdef __WXMSW__
 	void OnEraseBackground(wxEraseEvent& event);
 #endif
