@@ -1,7 +1,10 @@
 #ifndef __LISTCTRLEX_H__
 #define __LISTCTRLEX_H__
 
-class wxListCtrlEx : public wxListCtrl
+#include "systemimagelist.h"
+#include <wx/dnd.h>
+
+class wxListCtrlEx : public wxListCtrl, public CSystemImageList
 {
 public:
 	wxListCtrlEx(wxWindow *parent,
@@ -19,7 +22,7 @@ public:
 	void EnablePrefixSearch(bool enable) { m_prefixSearch_enabled = enable; }
 
 	// Reducing item count does not reset the focused item
- 	// if using the generic list control. Work around it.
+	// if using the generic list control. Work around it.
 	void SaveSetItemCount(long count);
 
 	void ShowColumnEditor();
@@ -29,10 +32,10 @@ public:
 	// Moves column. Target position includes both hidden
 	// as well as shown columns
 	void MoveColumn(unsigned int col, unsigned int before);
-	
+
 	// Do not call after calling LoadColumnSettings
 	void AddColumn(const wxString& name, int align, int initialWidth, bool fixed = false);
-	
+
 	// LoadColumnSettings needs to be called exactly once after adding
 	// all columns
 	void LoadColumnSettings(int widthsOptionId, int visibilityOptionId, int sortOptionId);
@@ -47,8 +50,14 @@ public:
 	void SetLabelEditBlock(bool block);
 
 #ifndef __WXMSW__
-	wxScrolledWindow* GetMainWindow();
+	wxScrolledWindow* GetMainWindow() const;
 #endif
+
+	bool HasSelection() const;
+
+	// Returns the true rect of the area containing the actual list items
+	wxRect GetListRect() const;
+
 protected:
 	virtual void OnPostScroll();
 	virtual void OnPreEmitPostScrollEvent();
@@ -60,15 +69,26 @@ protected:
 	void ResetSearchPrefix();
 
 	// Argument is visible column index
-	int GetHeaderIconIndex(int col);
-	void SetHeaderIconIndex(int col, int icon);
+	int GetHeaderSortIconIndex(int col);
+	void SetHeaderSortIconIndex(int col, int icon);
+
+	// Has to be called after setting the image list for the items
+	void InitHeaderSortImageList();
+#ifdef __WXMSW__
+	wxImageListEx *m_pHeaderImageList;
+#endif
+	struct _header_icon_index
+	{
+		int up;
+		int down;
+	} m_header_icon_index;
 
 private:
 	// Keyboard prefix search
 	void HandlePrefixSearch(wxChar character);
 	int FindItemWithPrefix(const wxString& searchPrefix, int start);
 
-	DECLARE_EVENT_TABLE();
+	DECLARE_EVENT_TABLE()
 	void OnPostScrollEvent(wxCommandEvent& event);
 	void OnScrollEvent(wxScrollWinEvent& event);
 	void OnMouseWheel(wxMouseEvent& event);
@@ -122,4 +142,35 @@ private:
 	wxListCtrlEx& m_listCtrl;
 };
 
+class CListCtrlDropTarget : public wxEvtHandler, public wxDropTarget
+{
+public:
+	CListCtrlDropTarget(wxListCtrlEx* pListCtrl);
+
+	virtual bool OnDrop(wxCoord x, wxCoord y);
+
+	virtual wxDragResult OnDragOver(wxCoord x, wxCoord y, wxDragResult def);
+
+	virtual void OnLeave();
+
+	virtual wxDragResult OnEnter(wxCoord x, wxCoord y, wxDragResult def);
+
+	virtual void DisplayDropHighlight(wxPoint) = 0;
+
+protected:
+	bool IsScroll(wxPoint p) const;
+	bool IsTopScroll(wxPoint p) const;
+	bool IsBottomScroll(wxPoint p) const;
+
+	void OnTimer(wxTimerEvent& /*event*/);
+
+protected:
+	wxListCtrlEx *m_pListCtrl;
+
+	wxTimer m_timer;
+	int m_count;
+
+	DECLARE_EVENT_TABLE()
+};
+
 #endif //__LISTCTRLEX_H__
