@@ -2,10 +2,11 @@
 
 #if FZ_MANUALUPDATECHECK
 
-#include "updatewizard.h"
-#include "filezillaapp.h"
-#include "Options.h"
 #include "buildinfo.h"
+#include "filezillaapp.h"
+#include "sizeformatting.h"
+#include "updatewizard.h"
+#include "Options.h"
 #include <wx/stdpaths.h>
 #include "Mainfrm.h"
 #ifdef __WXMSW__
@@ -80,6 +81,11 @@ PqQuF7sJR6POArUVYkRD/2LIWsB7\n\
 class CUpdateWizardOptions : public COptionsBase
 {
 public:
+	CUpdateWizardOptions()
+		: m_use_internal_rootcert(true)
+	{
+	}
+
 	virtual int GetOptionVal(unsigned int nID)
 	{
 		return COptions::Get()->GetOptionVal(nID);
@@ -87,7 +93,7 @@ public:
 
 	virtual wxString GetOption(unsigned int nID)
 	{
-		if (nID == OPTION_INTERNAL_ROOTCERT)
+		if (nID == OPTION_INTERNAL_ROOTCERT && m_use_internal_rootcert)
 			return s_update_cert;
 
 		return COptions::Get()->GetOption(nID);
@@ -102,6 +108,8 @@ public:
 	{
 		return COptions::Get()->SetOption(nID, value);
 	}
+
+	bool m_use_internal_rootcert;
 };
 
 CUpdateWizard::CUpdateWizard(wxWindow* pParent)
@@ -183,7 +191,7 @@ bool CUpdateWizard::Load()
 
 
 	GetPageAreaSizer()->Add(m_pages[0]);
-	
+
 	std::vector<wxWindow*> windows;
 	for (unsigned int i = 0; i < m_pages.size(); i++)
 		windows.push_back(m_pages[i]);
@@ -271,7 +279,7 @@ void CUpdateWizard::OnCheck(wxCommandEvent& event)
 
 #ifdef __WXMSW__
 // See comment a few lines below
-GUID VISTASHIT_FOLDERID_Downloads = { 0x374de290, 0x123f, 0x4565, 0x91, 0x64, 0x39, 0xc4, 0x92, 0x5e, 0x46, 0x7b };
+GUID VISTASHIT_FOLDERID_Downloads = { 0x374de290, 0x123f, 0x4565, { 0x91, 0x64, 0x39, 0xc4, 0x92, 0x5e, 0x46, 0x7b } };
 extern "C" typedef HRESULT (WINAPI *tSHGetKnownFolderPath)(const GUID& rfid, DWORD dwFlags, HANDLE hToken, PWSTR *ppszPath);
 #endif
 
@@ -280,7 +288,7 @@ CLocalPath CUpdateWizard::GetDownloadDir() const
 #ifdef __WXMSW__
 	// Old Vista has a profile directory for downloaded files,
 	// need to get it using SHGetKnownFolderPath which we need to
-	// load dynamically to preserve forward compatibility with the 
+	// load dynamically to preserve forward compatibility with the
 	// upgrade to Windows XP.
 	wxDynamicLibrary lib(_T("shell32.dll"));
 	if (lib.IsLoaded() && lib.HasSymbol(_T("SHGetKnownFolderPath")))
@@ -293,11 +301,11 @@ CLocalPath CUpdateWizard::GetDownloadDir() const
 		{
 			wxString dir = path;
 			CoTaskMemFree(path);
-			return dir;
+			return CLocalPath(dir);
 		}
 	}
 #endif
-	return wxStandardPaths::Get().GetDocumentsDir();
+	return CLocalPath(wxStandardPaths::Get().GetDocumentsDir());
 }
 
 bool CUpdateWizard::SetLocalFile()
@@ -311,7 +319,7 @@ bool CUpdateWizard::SetLocalFile()
 	CLocalPath downloadDir(COptions::Get()->GetOption(OPTION_UPDATECHECK_DOWNLOADDIR));
 	if (downloadDir.empty() || !downloadDir.Exists())
 		downloadDir = defaultDownloadDir;
-	
+
 	const int flags = wxFD_SAVE | wxFD_OVERWRITE_PROMPT;
 
 	const wxString& ext = filename.Right(4);
@@ -387,7 +395,7 @@ void CUpdateWizard::OnPageChanging(wxWizardEvent& event)
 			return;
 		}
 	}
-	
+
 	m_skipPageChanging = false;
 }
 
@@ -418,6 +426,9 @@ void CUpdateWizard::OnPageChanged(wxWizardEvent& event)
 
 	m_inTransfer = false;
 
+	if (m_update_options)
+		m_update_options->m_use_internal_rootcert = false;
+
 	int res = m_pEngine->Command(CConnectCommand(CServer(m_urlProtocol, DEFAULT, m_urlServer, (m_urlProtocol == HTTPS) ? 443 : 80)));
 	if (res == FZ_REPLY_OK)
 	{
@@ -453,9 +464,9 @@ void CUpdateWizard::FailedTransfer()
 		XRCCTRL(*this, "ID_FAILURE", wxStaticText)->SetLabel(_("Failed to check for newer version of FileZilla."));
 	else
 		XRCCTRL(*this, "ID_FAILURE", wxStaticText)->SetLabel(_("Failed to download the latest version of FileZilla."));
-	
+
 	((wxWizardPageSimple*)GetCurrentPage())->SetNext(m_pages[3]);
-	m_pages[3]->SetPrev((wxWizardPageSimple*)GetCurrentPage());	
+	m_pages[3]->SetPrev((wxWizardPageSimple*)GetCurrentPage());
 
 	m_skipPageChanging = true;
 	ShowPage(m_pages[3]);
@@ -519,7 +530,7 @@ void CUpdateWizard::OnEngineEvent(wxEvent& event)
 					else if (m_currentPage == 2)
 					{
 						wxStaticText *pText = XRCCTRL(*this, "ID_DOWNLOADPROGRESSTEXT", wxStaticText);
-						
+
 						wxString text = pLogMsg->msg;
 						text.Replace(_T("&"), _T("&&"));
 						WrapText(pText, text, m_pages[2]->GetClientSize().x);
@@ -721,7 +732,7 @@ void CUpdateWizard::ParseData()
 			m_news.Trim(false);
 			break;
 		}
-		
+
 		// Extract type of update
 		pos = line.Find(' ');
 		if (pos < 1)
@@ -871,7 +882,7 @@ void CUpdateWizard::SetTransferStatus(const CTransferStatus* pStatus)
 		return;
 	}
 
-	
+
 	wxTimeSpan elapsed = wxDateTime::Now().Subtract(pStatus->started);
 	int elapsedSeconds = elapsed.GetSeconds().GetLo(); // Assume GetHi is always 0
 
@@ -880,12 +891,15 @@ void CUpdateWizard::SetTransferStatus(const CTransferStatus* pStatus)
 	{
 		wxFileOffset rate = (pStatus->currentOffset - pStatus->startOffset) / elapsedSeconds;
 
-        if (rate > (1000*1000))
-			text.Printf(_("%s bytes (%d.%d MB/s)"), wxLongLong(pStatus->currentOffset).ToString().c_str(), (int)(rate / 1000 / 1000), (int)((rate / 1000 / 100) % 10));
-		else if (rate > 1000)
-			text.Printf(_("%s bytes (%d.%d KB/s)"), wxLongLong(pStatus->currentOffset).ToString().c_str(), (int)(rate / 1000), (int)((rate / 100) % 10));
-		else
-			text.Printf(_("%s bytes (%d B/s)"), wxLongLong(pStatus->currentOffset).ToString().c_str(), (int)rate);
+		CSizeFormat::_format format = static_cast<CSizeFormat::_format>(COptions::Get()->GetOptionVal(OPTION_SIZE_FORMAT));
+		if (format == CSizeFormat::bytes)
+			format = CSizeFormat::iec;
+		const wxString ratestr = CSizeFormat::Format(rate, true,
+													 format,
+													 COptions::Get()->GetOptionVal(OPTION_SIZE_USETHOUSANDSEP) != 0,
+													 COptions::Get()->GetOptionVal(OPTION_SIZE_DECIMALPLACES));
+
+		text.Printf(_("%s bytes (%s/s)"), wxLongLong(pStatus->currentOffset).ToString().c_str(), ratestr.c_str());
 
 		if (pStatus->totalSize > 0 && rate > 0)
 		{
@@ -907,7 +921,7 @@ void CUpdateWizard::SetTransferStatus(const CTransferStatus* pStatus)
 	m_pages[2]->GetSizer()->Layout();
 
 	if (pStatus->totalSize > 0)
-	{	
+	{
 		int percent = (pStatus->currentOffset * 100) / pStatus->totalSize;
 		if (percent > 100)
 			percent = 100;
@@ -961,7 +975,7 @@ bool CUpdateWizard::CanAutoCheckForUpdateNow()
 	if (lastCheckStr == _T(""))
 		return true;
 
-	wxDateTime lastCheck;	
+	wxDateTime lastCheck;
 	lastCheck.ParseDateTime(lastCheckStr);
 	if (!lastCheck.IsValid())
 		return true;
@@ -971,7 +985,7 @@ bool CUpdateWizard::CanAutoCheckForUpdateNow()
 	if (span.GetSeconds() < 0)
 		// Last check in future
 		return true;
-	
+
 	int days;
 	if (CBuildInfo::GetBuildType() == _T("official") && CBuildInfo::IsUnstable())
 		days = 3600 * 24;
@@ -990,6 +1004,7 @@ void CUpdateWizard::StartUpdateCheck()
 	if (COptions::Get()->GetOptionVal(OPTION_UPDATECHECK_CHECKBETA) != 0)
 		m_urlFile += _T("&beta=1");
 
+	m_update_options->m_use_internal_rootcert = true;
 	int res = m_pEngine->Command(CConnectCommand(CServer(m_urlProtocol, DEFAULT, m_urlServer, (m_urlProtocol == HTTPS) ? 443 : 80)));
 	if (res == FZ_REPLY_OK)
 	{
@@ -1082,7 +1097,13 @@ void CUpdateWizard::PrepareUpdateAvailablePage(const wxString &newVersion, wxStr
 	}
 	else
 	{
-		if (!newUrl.Left(7).CmpNoCase(_T("http://")))
+		m_urlProtocol = HTTP;
+		if (!newUrl.Left(8).CmpNoCase(_T("https://")))
+		{
+			newUrl = newUrl.Mid(8);
+			m_urlProtocol = HTTPS;
+		}
+		else if (!newUrl.Left(7).CmpNoCase(_T("http://")))
 			newUrl = newUrl.Mid(7);
 		int pos = newUrl.Find('/');
 		if (pos == -1)
@@ -1097,7 +1118,6 @@ void CUpdateWizard::PrepareUpdateAvailablePage(const wxString &newVersion, wxStr
 			XRCCTRL(*this, "ID_UPDATEDESC2", wxStaticText)->SetLabel(_("Alternatively, visit http://filezilla-project.org to download the most recent version."));
 			XRCCTRL(*this, "ID_UPDATEDESC2", wxStaticText)->Show();
 
-			m_urlProtocol = HTTP;
 			m_urlServer = newUrl.Left(pos);
 			m_urlFile = newUrl.Mid(pos);
 			m_update_checksum = newChecksum;
@@ -1245,9 +1265,9 @@ void CUpdateWizard::FailedChecksum()
 	XRCCTRL(*this, "ID_MISMATCH2", wxStaticText)->Show();
 	XRCCTRL(*this, "ID_MISMATCH3", wxStaticText)->Show();
 	XRCCTRL(*this, "ID_MISMATCH4", wxStaticText)->Show();
-	
+
 	((wxWizardPageSimple*)GetCurrentPage())->SetNext(m_pages[3]);
-	m_pages[3]->SetPrev((wxWizardPageSimple*)GetCurrentPage());	
+	m_pages[3]->SetPrev((wxWizardPageSimple*)GetCurrentPage());
 
 	m_skipPageChanging = true;
 	ShowPage(m_pages[3]);
