@@ -68,7 +68,7 @@ static int calcYear(int month, int day)
 void CDirectoryListingParserTest::InitEntries()
 {
 	// Unix-style listings
-        // -------------------
+	// -------------------
 
 	// We start with a perfect example of a unix style directory listing without anomalies.
 	m_entries.push_back((t_entry){
@@ -296,7 +296,7 @@ void CDirectoryListingParserTest::InitEntries()
 	utc = wxDateTime(13, wxDateTime::Feb, 1996, 23, 58, 27);
 	utc.MakeFromTimezone(wxDateTime::UTC);
 	m_entries.push_back((t_entry){
-        	"+i8388621.50690,m824255907,/,\t15-eplf dir",
+			"+i8388621.50690,m824255907,/,\t15-eplf dir",
 			{
 				_T("15-eplf dir"),
 				-1,
@@ -512,6 +512,20 @@ void CDirectoryListingParserTest::InitEntries()
 			DEFAULT
 		});
 
+	m_entries.push_back((t_entry){
+			"dr-xr-xr-x   2 root     other      2235 szept 26 20:10 28b-datetest-hungarian dir",
+			{
+				_T("28b-datetest-hungarian dir"),
+				2235,
+				_T("dr-xr-xr-x"),
+				_T("root other"),
+				CDirentry::flag_dir | CDirentry::flag_timestamp_date | CDirentry::flag_timestamp_time,
+				_T(""),
+				wxDateTime(26, wxDateTime::Sep, calcYear(7, 26), 20, 10)
+			},
+			DEFAULT
+		});
+
 	m_entries.push_back((t_entry){
 			"-r-xr-xr-x   2 root     other      2235 2.   Okt.  2003 29-datetest-ger file",
 			{
@@ -1056,11 +1070,11 @@ void CDirectoryListingParserTest::InitEntries()
 	});
 
 	// MVS Dataset members
-	// 
+	//
 	// As common with IBM misdesign, multiple styles exist.
-	
+
 	// Speciality: Some members have no attributes at all.
-	// Requires servertype to be MVS or it won't be parsed, as 
+	// Requires servertype to be MVS or it won't be parsed, as
 	// it would conflict with lots of other servers.
 	m_entries.push_back((t_entry){
 			"65-MVS-PDS-MEMBER",
@@ -1137,7 +1151,7 @@ void CDirectoryListingParserTest::InitEntries()
 
 	// z/VM, another IBM abomination. Description by Alexandre Charbey
 	// Requires type set to ZVM or it cannot be parsed.
-	// 
+	//
 	// 70-ZVMFILE
 	//   is a filename
 	// TRACE
@@ -1257,7 +1271,7 @@ void CDirectoryListingParserTest::InitEntries()
 				utc
 			},
 			DEFAULT
-		});	
+		});
 
 		m_entries.push_back((t_entry){
 			"type=OS.unix=slink:/foo; 76 MLSD symlink",
@@ -1271,7 +1285,7 @@ void CDirectoryListingParserTest::InitEntries()
 				wxDateTime()
 			},
 			DEFAULT
-		});	
+		});
 
 		// Old ietf draft for MLST earlier than mlst-07 has no trailing semicolon after facts
 		m_entries.push_back((t_entry){
@@ -1334,13 +1348,30 @@ void CDirectoryListingParserTest::InitEntries()
 		DEFAULT
 	});
 
+	// MVS entry with a large number of used blocks:
+	// http://forum.filezilla-project.org/viewtopic.php?t=21667
+	// Volume Unit    Referred Ext Used Recfm Lrecl BlkSz Dsorg Dsname
+	m_entries.push_back((t_entry){
+			"GISBWI 3390   2011/08/25  2 ++++  FB     904 18080  PS  80-MVS.FILE",
+			{
+				_T("80-MVS.FILE"),
+				100,
+				_T(""),
+				_T(""),
+				CDirentry::flag_timestamp_date,
+				_T(""),
+				wxDateTime(25, wxDateTime::Aug, 2011)
+		},
+		DEFAULT
+	});
+
 	// MVS entry with PO-E Dsorg indicating direrctory. See
 	// http://forum.filezilla-project.org/viewtopic.php?t=19374 for reference.
 	// Volume Unit    Referred Ext Used Recfm Lrecl BlkSz Dsorg Dsname
 	m_entries.push_back((t_entry){
-			"WYOSPT 3420   2003/05/21  1 3 U 6447    6447  PO-E 80-MVS.DIR",
+			"WYOSPT 3420   2003/05/21  1 3 U 6447    6447  PO-E 81-MVS.DIR",
 			{
-				_T("80-MVS.DIR"),
+				_T("81-MVS.DIR"),
 				-1,
 				_T(""),
 				_T(""),
